@@ -54,6 +54,7 @@ define([
                 sizeLevel: 0,          // 0: 400x400 / 1: 500x500 / 2: 600x500 / 3: 750x500
                 executeMode: 'code',   // cell execute mode
                 // show header bar buttons
+                installButton: false, // install button (#popupInstall) // FIXME: after creating packagemanager, deprecate it
                 importButton: false,  // import library button (#popupImport)
                 packageButton: false, // package manager button (#popupPackage)
                 // show view box
@@ -257,6 +258,15 @@ define([
                 });
             });
 
+            // Click install package
+            $(this.wrapSelector('#popupInstall')).on('click', function() {
+                // add install codes
+                var codes = that.generateInstallCode();
+                codes && codes.forEach(code => {
+                    com_interface.insertCell('code', code);
+                });
+            });
+
             // Click import library
             $(this.wrapSelector('#popupImport')).on('click', function() {
                 // add import codes
@@ -475,12 +485,15 @@ define([
             super.render(inplace);
 
             let { 
-                importButton, packageButton, 
+                installButton, importButton, packageButton, 
                 codeview, dataview, runButton, footer, 
                 sizeLevel, position
             } = this.config;
 
             // import & package manager button hide/show
+            if (!installButton) { // FIXME: Deprecated after creating package manager
+                $(this.wrapSelector('#popupInstall')).hide();
+            }
             if (!importButton) {
                 $(this.wrapSelector('#popupImport')).hide();
             }
@@ -574,6 +587,15 @@ define([
             $('.vp-popup-dataview-box').html(this.templateForDataView());
         }
 
+        /**
+         * Generated on clicking Install Package button
+         * @returns Array of installment codes
+         */
+        generateInstallCode() {
+            /** Implementation needed - Generated on clicking Install Package button */
+            return [];
+        }
+
         generateImportCode() {
             /** Implementation needed - Generated on clicking Import Library button */
             return '';
